@@ -4,10 +4,11 @@ from .asserts import *
 from .annotations import *
 from .classes.soft_assert import SoftAssert
 from .classes.fluent_assert import verify
-from .classes.spy import Spy
+from .classes.spy import Spy, Double
 from .classes.listeners.file_logger import DefaultFileListener
 
-__all__ = ['start', 'common_parameters', 'SoftAssert', 'Spy', 'DefaultFileListener',
+__all__ = ['start', 'common_parameters', 'SoftAssert', 'Spy', 'Double', 'DefaultFileListener',
            'equals', 'is_none', 'not_none', 'waiting_exception', 'test_fail', 'test_brake', 'no_exception_expected',
            'contains', 'verify', 'not_contains', 'not_equals', 'is_false', 'is_true', 'mock_builtins', 'mock',
+           'is_zero', 'is_positive', 'is_negative',
            'test', 'before', 'after', 'before_group', 'after_group', 'before_suite', 'after_suite', 'data']
