@@ -25,8 +25,15 @@ class DefaultListener(Listener):
         print(f'Starting suite "{test_suite.name}"')
 
     def on_empty_suite(self, test_suite: TestSuite):
+        super().on_empty_suite(test_suite)
         print('No tests were found! Stopped...')
 
+    def on_dry_run(self, test_suite: TestSuite):
+        super().on_dry_run(test_suite)
+        print_splitter_line()
+        print("DRY RUN MODE! No real tests will be executed! All fixtures will be ignored!")
+        print_splitter_line()
+
     def on_suite_ends(self, test_suite: TestSuite):
         super().on_suite_ends(test_suite)
         if not self.verbose:
@@ -98,7 +105,10 @@ class DefaultListener(Listener):
     def on_ignored_by_condition(self, group: TestGroup, test: TestCase, exc: Exception):
         super().on_ignored_by_condition(group, test, exc)
         add_ = '' if not test.argument else f'[{short(test.argument)}]'
-        print(f'Test "{test}" {add_} ignored because of condition!')
+        if type(exc) is SystemExit:
+            print(f'Test "{test}" {add_} ignored because of sys.exit() call inside function!')
+        else:
+            print(f'Test "{test}" {add_} ignored because of condition ({test.only_if.__module__}.{test.only_if})!')
 
     def _failed_or_broken(self, test, exception_, _result):
         _letter = f'{_result.upper()}!'
